@@ -3,7 +3,7 @@ BEGIN {
   $Constant::Export::Lazy::AUTHORITY = 'cpan:AVAR';
 }
 {
-  $Constant::Export::Lazy::VERSION = '0.13';
+  $Constant::Export::Lazy::VERSION = '0.14';
 }
 use 5.006;
 use strict;
@@ -88,18 +88,6 @@ sub import {
             # subclassing actually re-generated constants.
             pkg_stash => $caller,
 
-            # This is the symbol table for the package that's implementing
-            # the constant exporter, not the user package requesting
-            # constant to be exported to it.
-            #
-            # Really important distinction because we never want to
-            # re-generate the same constant again when another package
-            # requests it.
-            symtab => do {
-                no strict 'refs';
-                \%{"${caller}::"};
-            },
-
             # If we're not wrapping an existing import subroutine we
             # don't need to bend over backwards to support constants
             # generated by e.g. constant.pm, we know we've made all
@@ -202,7 +190,6 @@ sub Constant::Export::Lazy::Ctx::call {
     my ($ctx, $gimme) = @_;
 
     # Unpack our options
-    my $symtab               = $ctx->{symtab};
     my $pkg_importer         = $ctx->{pkg_importer};
     my $pkg_stash            = $ctx->{pkg_stash};
     my $constants            = $ctx->{constants};
@@ -241,19 +228,12 @@ sub Constant::Export::Lazy::Ctx::call {
         # This is in case $ctx->call() is used on a constant defined
         # by constant.pm. See the giant comment about constant.pm
         # below.
-        my $symtab_value = $symtab->{$gimme};
-        my $ref = ref $symtab_value;
-        if (not defined $symtab_value) {
-            die "PANIC: We're trying to fallback to a constant we don't know about under wrap_existing_import, but $gimme has no symbol table entry";
-        } elsif ($ref eq 'SCALAR' or $ref eq 'REF') {
-            $value = $$symtab_value;
-        } elsif (ref $symtab_value eq 'ARRAY') {
-            $value = $symtab_value;
-        } else {
-            my @value = &$symtab_value();
-            die "PANIC: We only support subs that return one value with wrap_existing_import, $gimme returns " . @value . " values"
-                if @value > 1;
+        if (my $code = $pkg_stash->can($gimme)) {
+            my @value = $code->();
+            die "PANIC: We only support subs that return one value with wrap_existing_import, $gimme returns " . @value . " values" if @value > 1;
             $value = $value[0];
+        } else {
+            die "PANIC: We're trying to fallback to a constant we don't know about under wrap_existing_import, but $gimme has no symbol table entry";
         }
     } elsif (do {
         # Check if this is a constant we've defined already, in which
@@ -265,12 +245,11 @@ sub Constant::Export::Lazy::Ctx::call {
         # constant.
         $make_private_glob_and_alias_name->();
 
-        exists $symtab->{$private_name};
+        $pkg_stash->can($private_name);
     }) {
         # This is for constants that *we've* previously defined, we'll
         # always use our own $private_name.
-        my $symtab_value = $symtab->{$private_name};
-        $value = &$symtab_value();
+        $value = $pkg_stash->can($private_name)->();
     } else {
         my $override = $constants->{$gimme}->{options}->{override};
         my $stash    = $constants->{$gimme}->{options}->{stash};
@@ -311,7 +290,8 @@ sub Constant::Export::Lazy::Ctx::call {
             # it's true that `$] > 5.009002`:
             #
             #     Internals::SvREADONLY($value, 1);
-            #     $symtab->{$gimme} = \$value;
+            #     my $stash = \%{"$pkg_stash::"};
+            #     $stash->{$gimme} = \$value;
             #
             # This would save some space for perl when producing
             # these inline constants. The reason I'm not doing
